.. _api_ref:

=============
API Reference
=============

This page contains the documentation of the public API. The :py:class:`pharmpy.model` module includes the model object
and the classes related to it (parameters, statements, random variables etc.), the :py:class:`pharmpy.modeling` module
handles different transformations and manipulations, and the :py:class:`pharmpy.tools` module handles model estimation
and tools. The :py:class:`pharmpy.workflows` module handles how different tools are built and run.

.. note::

    `pharmr <https://github.com/pharmpy/pharmr/>`_ only includes functions from :doc:`api_modeling` and
    :doc:`api_tools`.

.. toctree::
   :maxdepth: 1

   api_model
   api_modeling
   api_tools
   api_workflows
